from pandas import DataFrame, read_csv
from sklearn.preprocessing import LabelEncoder
from sklearn.model_selection import KFold


def construct_dataframes(train, test):
    file_list = [train, test]
    df_dict = {}
    for file in file_list:
        df_dict[file] = read_csv(filepath_or_buffer=file)
    df_list = list(df_dict.values())
    return df_list


def drop_null_values(df_list):
    for df in df_list:
        df.dropna(inplace=True)
        df.drop(columns="Tipo_marchas", inplace=True)
    return df_list


def rename_columns(df_list) -> DataFrame:
    for df in df_list:
        df.columns = df.columns.str.lower()
    return df_list


def trim_column_names(df_list) -> DataFrame:
    columns = ["consumo", "motor_CC", "potencia"]
    for df in df_list:
        for col in columns:
            df[col] = df[col].str.replace(pat="[^.0-9]", repl="").astype(float)
    return df_list


def encode_columns(df_list):
    label_encoder = LabelEncoder()
    files = [
        "ao"
        "asientos"
        "ciudad"
        "combustible"
        "consumo"
        "descuento"
        "kilometros"
        "mano"
        "motor_cc"
        "nombre"
        "potencia"
    ]
    for data in files:
        for df in df_list:
            label = label_encoder.fit(read_csv("data/" + data + ".csv", squeeze=True))
            df[data] = label.transform(df[data])
    return df_list


def split_k_sets(df):
    k_fold = KFold(shuffle=True, random_state=42)
    return k_fold.split(df)


def parse_data(train, test):
    df_list = construct_dataframes(train=train, test=test)
    renamed_df_list = rename_columns(df_list)
    processed_df_list = drop_null_values(renamed_df_list)
    numeric_df_list = trim_column_names(processed_df_list)
    encoded_df_list = encode_columns(numeric_df_list)
    return encoded_df_list
